@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21283 $
- * $Author: rjongbloed $
- * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #ifndef OPAL_CODEC_OPALPLUGIN_H
@@ -502,10 +502,10 @@ enum {
 // Video Capabilities
 
 // H264 (as defined in H.241)
-#define OpalPluginCodec_Identifer_H264            "0.0.8.241.0.0.0.0"
-#define OpalPluginCodec_Identifer_H264_RFC3984    "0.0.8.241.0.0.0.1"
-#define OpalPluginCodec_Identifer_H264_RFC3984Int "0.0.8.241.0.0.0.2"
-#define OpalPluginCodec_Identifer_H264_Generic    "0.0.8.241.0.0.1"
+#define OpalPluginCodec_Identifer_H264_Aligned        "0.0.8.241.0.0.0.0"
+#define OpalPluginCodec_Identifer_H264_NonInterleaved "0.0.8.241.0.0.0.1"
+#define OpalPluginCodec_Identifer_H264_Interleaved    "0.0.8.241.0.0.0.2"
+#define OpalPluginCodec_Identifer_H264_Generic        "0.0.8.241.0.0.1"
 
 // ISO/IEC 14496-2 MPEG4 part 2 (as defined in H.245v13 Annex E)
 #define OpalPluginCodec_Identifer_MPEG4           "0.0.8.245.1.0.0"
