@@ -26,10 +26,14 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
+
+#ifndef OPAL_H323_H323_H
+#define OPAL_H323_H323_H
+
 #include <opal/buildopts.h>
 
 #include <h323/h323ep.h>
@@ -43,4 +47,6 @@ unsigned OpalGetMinorVersion();
 unsigned OpalGetBuildNumber();
 
 
+#endif // OPAL_H323_H323_H
+
 /////////////////////////////////////////////////////////////////////////////
