@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_ENDPOINT_H
-#define __OPAL_ENDPOINT_H
+#ifndef OPAL_OPAL_ENDPOINT_H
+#define OPAL_OPAL_ENDPOINT_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -162,7 +162,7 @@ class OpalEndPoint : public PObject
       */
     OpalTransportAddressArray GetInterfaceAddresses(
       PBoolean excludeLocalHost = PTrue,       ///<  Flag to exclude 127.0.0.1
-      OpalTransport * associatedTransport = NULL
+      const OpalTransport * associatedTransport = NULL
                           ///<  Associated transport for precedence and translation
     );
 
@@ -631,7 +631,9 @@ class OpalEndPoint : public PObject
 
     /**Set the default local party name for all connections on this endpoint.
       */
-    void SetDefaultLocalPartyName(const PString & name) { defaultLocalPartyName = name; }
+    virtual void SetDefaultLocalPartyName(
+      const PString & name  /// Name for local party
+    ) { defaultLocalPartyName = name; }
 
     /**Get the default local display name for all connections on this endpoint.
       */
@@ -705,7 +707,7 @@ class OpalEndPoint : public PObject
 };
 
 
-#endif // __OPAL_ENDPOINT_H
+#endif // OPAL_OPAL_ENDPOINT_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
