@@ -28,13 +28,13 @@
  *     US Joint Forces Command Joint Concept Development & Experimentation (J9)
  *     http://www.jfcom.mil/about/abt_j9.htm
  *
- * $Revision: 21115 $
- * $Author: rjongbloed $
- * $Date: 2008-09-22 03:00:58 +0000 (Mon, 22 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_TRANSPORT_H
-#define __OPAL_TRANSPORT_H
+#ifndef OPAL_OPAL_TRANSPORT_H
+#define OPAL_OPAL_TRANSPORT_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -363,23 +363,6 @@ class OpalListener : public PObject
 PLIST(OpalListenerList, OpalListener);
 
 
-/** Return a list of transport addresses corresponding to a listener list
-  */
-OpalTransportAddressArray OpalGetInterfaceAddresses(
-  const OpalListenerList & listeners,  ///<  List of listeners
-  bool excludeLocalHost,               ///<  Flag to exclude 127.0.0.1
-  OpalTransport * associatedTransport, ///<  Associated transport for precedence and translation
-  PNatMethod * natMethod               ///< NAT traversal method, e.g. STUN server if used
-);
-
-OpalTransportAddressArray OpalGetInterfaceAddresses(
-  const OpalTransportAddress & addr,   ///<  Possible INADDR_ANY address
-  bool excludeLocalHost,               ///<  Flag to exclude 127.0.0.1
-  OpalTransport * associatedTransport, ///<  Associated transport for precedence and translation
-  PNatMethod * natMethod               ///< NAT traversal method, e.g. STUN server if used
-);
-
-
 class OpalListenerIP : public OpalListener
 {
   PCLASSINFO(OpalListenerIP, OpalListener);
@@ -785,9 +768,12 @@ class OpalTransport : public PIndirectChannel
       */
     virtual const char * GetProtoPrefix() const = 0;
 
+    PMutex & GetWriteMutex() { return m_writeMutex; }
+
   protected:
     OpalEndPoint & endpoint;
     PThread      * thread;      ///<  Thread handling the transport
+    PMutex         m_writeMutex;
 };
 
 
@@ -1247,7 +1233,7 @@ typedef OpalInternalIPTransportTemplate<OpalListenerTCPS, OpalTransportTCPS, Opa
 #endif // OPAL_PTLIB_SSL
 
 
-#endif  // __OPAL_TRANSPORT_H
+#endif  // OPAL_OPAL_TRANSPORT_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
