@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20763 $
- * $Author: rjongbloed $
- * $Date: 2008-08-29 03:06:49 +0200 (ven 29 aoû 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include "stdafx.h"
@@ -41,6 +41,10 @@
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
+#define TRACE_OPTIONS "TraceLevel=4 TraceFile=\\MobileOpalLog.txt"
+//#define TRACE_OPTIONS "TraceLevel=4"
+#else
+#define TRACE_OPTIONS "TraceLevel=4 TraceAppend TraceFile=\\MobileOpalLog.txt"
 #endif
 
 #define SPEAKERMODE_METHOD 3
@@ -54,6 +58,7 @@ static TCHAR const UserNameKey[]         = L"UserName";
 static TCHAR const DisplayNameKey[]      = L"DisplayName";
 static TCHAR const STUNServerKey[]       = L"STUNServer";
 static TCHAR const InterfaceAddressKey[] = L"InterfaceAddress";
+static TCHAR const AutoStartTxVideoKey[] = L"AutoStartTxVideo";
 static TCHAR const GkTypeKey[]           = L"GatekeeperType";
 static TCHAR const GkIdKey[]             = L"GatekeeperIdentifer";
 static TCHAR const GkHostKey[]           = L"GatekeeperHost";
@@ -81,9 +86,9 @@ static CStringA GetOptionStringA(LPCTSTR szKey, LPCTSTR szDefault = NULL)
 }
 
 
-static UINT GetOptionInt(LPCTSTR szKey)
+static UINT GetOptionInt(LPCTSTR szKey, int iDefault = 0)
 {
-  return AfxGetApp()->GetProfileInt(OptionsSection, szKey, 0);
+  return AfxGetApp()->GetProfileInt(OptionsSection, szKey, iDefault);
 }
 
 
@@ -295,6 +300,7 @@ CMobileOpalDlg::CMobileOpalDlg(CWnd* pParent /*=NULL*/)
   : CDialog(CMobileOpalDlg::IDD, pParent)
   , m_opal(NULL)
   , m_opalVersion(OPAL_C_API_VERSION)
+  , m_speakerphone(false)
 {
   m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
 }
@@ -404,7 +410,7 @@ void CMobileOpalDlg::InitialiseOPAL()
   // Start up and initialise OPAL
 
   if (m_opal == NULL) {
-    m_opal = OpalInitialise(&m_opalVersion, "pc h323 sip TraceLevel=4 TraceAppend TraceFile=\\MobileOpalLog.txt");
+    m_opal = OpalInitialise(&m_opalVersion, "pc h323 sip " TRACE_OPTIONS);
     if (m_opal == NULL) {
       ErrorBox(IDS_INIT_FAIL);
       EndDialog(IDCANCEL);
@@ -415,12 +421,87 @@ void CMobileOpalDlg::InitialiseOPAL()
   OpalMessage command;
   OpalMessage * response;
 
+  // SIP registrar un-regisration
+  CStringA strAOR = GetOptionStringA(RegistrarAorKey);
+  CStringA strHost = GetOptionStringA(RegistrarHostKey);
+  if (!m_currentAOR.IsEmpty() && (m_currentAOR != strAOR || m_currentHost != strHost)) {
+    // Registration changed, so unregister the previous name
+    memset(&command, 0, sizeof(command));
+    command.m_type = OpalCmdRegistration;
+    command.m_param.m_registrationInfo.m_protocol = "sip";
+    command.m_param.m_registrationInfo.m_identifier = m_currentAOR;
+    command.m_param.m_registrationInfo.m_hostName = m_currentHost;
+    response = OpalSendMessage(m_opal, &command);
+    if (response != NULL && response->m_type == OpalCmdRegistration) {
+      OpalFreeMessage(response);
+
+      UpdateWindow();
+
+      // Wait for unregister to complete.
+      while ((response = OpalGetMessage(m_opal, 30000)) != NULL) {
+        HandleMessage(*response);
+        if (response->m_type == OpalIndRegistration && response->m_param.m_registrationStatus.m_status == OpalRegisterRemoved)
+          break;
+      }
+    }
+    OpalFreeMessage(response);
+    m_currentAOR.Empty();
+    m_currentHost.Empty();
+  }
+
+  /* Calucalte some configuration strings, determine position of a QCIF
+     window so is in bottom left corner, and a preview window for camera
+     in lower right corner, scaled to fit remaining space. */
+  static const unsigned videoWidth = 176;
+  static const unsigned videoHeight = 144;
+  CRect box;
+  GetClientRect(&box);
+
+  CRect commandBox;
+  m_dlgCommandBar.GetWindowRect(&commandBox);
+  box.bottom -= commandBox.Height();
+
+  CStringA strVideoOutputDevice;
+  strVideoOutputDevice.Format("MSWIN STYLE=0x%08X PARENT=0x%08X X=%i Y=%i WIDTH=%u HEIGHT=%u",
+                              WS_CHILD|WS_BORDER, GetSafeHwnd(),
+                              0, box.Height()-videoHeight,
+                              videoWidth, videoHeight);
+
+  unsigned previewWidth = box.Width() - videoWidth - 2;
+  unsigned previewHeight = previewWidth*videoHeight/videoWidth;
+  CStringA strVideoPreviewDevice;
+  strVideoPreviewDevice.Format("MSWIN STYLE=0x%08X PARENT=0x%08X X=%i Y=%i WIDTH=%u HEIGHT=%u",
+                               WS_CHILD|WS_BORDER, GetSafeHwnd(),
+                               videoWidth+2, box.Height()-previewHeight,
+                               previewWidth, previewHeight);
+
+  CStringA strMediaOptions;
+  strMediaOptions.Format("Video:Max Bit Rate=128000\n"
+                         "Video:Target Bit Rate=128000\n"
+                         "Video:Frame Time=9000\n" // 10 frames/second
+                         "Video:Frame Width=%u\n"
+                         "Video:Frame Height=%u\n"
+                         "Video:Max Rx Frame Width=%u\n"
+                         "Video:Max Rx Frame Height=%u\n"
+                         "H.264:Level=1b\n",
+                          videoWidth, videoHeight,
+                          videoWidth, videoHeight);
+
   // General options
   memset(&command, 0, sizeof(command));
   command.m_type = OpalCmdSetGeneralParameters;
 
   CStringA strStunServer = GetOptionStringA(STUNServerKey);
   command.m_param.m_general.m_stunServer = strStunServer;
+  command.m_param.m_general.m_audioPlayerDevice = "Audio Output";
+  command.m_param.m_general.m_audioRecordDevice = "Audio Input";
+  command.m_param.m_general.m_videoInputDevice = "CAM1:";
+  command.m_param.m_general.m_videoOutputDevice = strVideoOutputDevice;
+  command.m_param.m_general.m_videoPreviewDevice = strVideoPreviewDevice;
+  command.m_param.m_general.m_mediaMask = "RFC4175*\nMPEG4";
+  command.m_param.m_general.m_mediaOptions = strMediaOptions;
+  command.m_param.m_general.m_autoTxMedia = GetOptionInt(AutoStartTxVideoKey, true) != 0 ? "audio video" : "audio";
+  command.m_param.m_general.m_rtpMaxPayloadSize = 1400;
 
   if ((response = OpalSendMessage(m_opal, &command)) == NULL || response->m_type == OpalIndCommandError)
     ErrorBox(IDS_CONFIGURATION_FAIL, response);
@@ -431,7 +512,7 @@ void CMobileOpalDlg::InitialiseOPAL()
   command.m_type = OpalCmdSetProtocolParameters;
 
   CStringA strUserName = GetOptionStringA(UserNameKey);
-  command.m_param.m_protocol.m_name = strUserName;
+  command.m_param.m_protocol.m_userName = strUserName;
 
   CStringA strDisplayName = GetOptionStringA(UserNameKey);
   command.m_param.m_protocol.m_displayName = strDisplayName;
@@ -472,19 +553,8 @@ void CMobileOpalDlg::InitialiseOPAL()
     OpalFreeMessage(response);
   }
 
-  // SIP registrar regisration
-  CStringA strAor = GetOptionStringA(RegistrarAorKey);
-  if (!m_currentRegistrar.IsEmpty() && m_currentRegistrar != strAor) {
-    // Registration changed, so unregister the previous name
-    memset(&command, 0, sizeof(command));
-    command.m_type = OpalCmdRegistration;
-    command.m_param.m_registrationInfo.m_protocol = "sip";
-    command.m_param.m_registrationInfo.m_identifier = m_currentRegistrar;
-    OpalFreeMessage(OpalSendMessage(m_opal, &command)); // Don't worry about errors.
-    m_currentRegistrar.Empty();
-  }
-
-  if (strAor.IsEmpty())
+  // SIP registrar registration
+  if (strAOR.IsEmpty())
     SetStatusText(IDS_READY);
   else {
     memset(&command, 0, sizeof(command));
@@ -492,9 +562,7 @@ void CMobileOpalDlg::InitialiseOPAL()
 
     command.m_param.m_registrationInfo.m_protocol = "sip";
 
-    command.m_param.m_registrationInfo.m_identifier = strAor;
-
-    CStringA strHost = GetOptionStringA(RegistrarHostKey);
+    command.m_param.m_registrationInfo.m_identifier = strAOR;
     command.m_param.m_registrationInfo.m_hostName = strHost;
 
     CStringA strAuthUser = GetOptionStringA(RegistrarUserKey);
@@ -507,15 +575,22 @@ void CMobileOpalDlg::InitialiseOPAL()
     command.m_param.m_registrationInfo.m_adminEntity = strRealm;
 
     command.m_param.m_registrationInfo.m_timeToLive = 300;
-    command.m_param.m_registrationInfo.m_messageWaiting = 300;
 
     SetStatusText(IDS_REGISTERING);
-    if ((response = OpalSendMessage(m_opal, &command)) != NULL && response->m_type != OpalIndCommandError)
-      m_currentRegistrar = strAor;
-    else {
+    if ((response = OpalSendMessage(m_opal, &command)) != NULL && response->m_type != OpalIndCommandError) {
+      m_currentAOR = strAOR;
+      m_currentHost = strHost;
+
+      OpalFreeMessage(response);
+      command.m_param.m_registrationInfo.m_eventPackage = OPAL_MWI_EVENT_PACKAGE;
+      response = OpalSendMessage(m_opal, &command);
+    }
+
+    if (response == NULL || response->m_type == OpalIndCommandError) {
       ErrorBox(IDS_REGISTRATION_FAIL, response);
       SetStatusText(IDS_READY);
     }
+
     OpalFreeMessage(response);
   }
 }
@@ -619,84 +694,7 @@ void CMobileOpalDlg::OnTimer(UINT_PTR nIDEvent)
   if (nIDEvent == TimerID && m_opal != NULL) {
     OpalMessage * message = OpalGetMessage(m_opal, 0);
     if (message != NULL) {
-      switch (message->m_type) {
-        case OpalIndRegistration :
-          switch (message->m_param.m_registrationStatus.m_status) {
-            case OpalRegisterSuccessful :
-            case OpalRegisterRestored :
-              SetStatusText(IDS_REGISTERED);
-              break;
-
-            case OpalRegisterRemoved :
-              SetStatusText(IDS_UNREGISTERED, message->m_param.m_registrationStatus.m_error);
-              break;
-
-            case OpalRegisterRetrying :
-              SetStatusText(IDS_REGISTERING);
-              break;
-
-            case OpalRegisterFailed :
-              SetStatusText(0, message->m_param.m_registrationStatus.m_error);
-          }
-          break;
-
-        case OpalIndMessageWaiting :
-          {
-            CStringA msg;
-            msg.Format(IDS_MESSAGE_WAITING,
-                       message->m_param.m_messageWaiting.m_type,
-                       message->m_param.m_messageWaiting.m_party);
-            SetStatusText(0, msg);
-          }
-          break;
-
-        case OpalIndIncomingCall :
-          if (m_incomingCallToken.IsEmpty() && m_currentCallToken.IsEmpty()) {
-            m_incomingCallToken = message->m_param.m_incomingCall.m_callToken;
-            SetStatusText(IDS_INCOMING_CALL);
-            SetCallButton(true, IDS_ANSWER);
-            m_ctrlCallAddress.EnableWindow(false);
-            ShowWindow(true);
-            BringWindowToTop();
-          }
-          else {
-            OpalMessage command;
-            memset(&command, 0, sizeof(command));
-            command.m_type = OpalCmdClearCall;
-            command.m_param.m_clearCall.m_callToken = message->m_param.m_incomingCall.m_callToken;
-            command.m_param.m_clearCall.m_reason = OpalCallEndedByAnswerDenied;
-            OpalMessage * response = OpalSendMessage(m_opal, &command);
-            if (response != NULL)
-              OpalFreeMessage(response);
-            SetStatusText(IDS_BUSY);
-          }
-          break;
-
-        case OpalIndAlerting :
-          SetStatusText(IDS_RINGING);
-          break;
-
-        case OpalIndEstablished :
-          SetSpeakerMode(m_speakerphone);
-          SetStatusText(IDS_ESTABLISHED);
-          break;
-
-        case OpalIndUserInput :
-          SetStatusText(0, message->m_param.m_userInput.m_userInput);
-          break;
-
-        case OpalIndCallCleared :
-          if (m_currentCallToken  == message->m_param.m_callCleared.m_callToken ||
-              m_incomingCallToken == message->m_param.m_callCleared.m_callToken) {
-            m_incomingCallToken.Empty();
-            m_currentCallToken.Empty();
-
-            SetCallButton(true, IDS_CALL);
-            m_ctrlCallAddress.EnableWindow(true);
-
-            SetStatusText(IDS_READY, message->m_param.m_callCleared.m_reason);
-          }
-      }
+      HandleMessage(*message);
       OpalFreeMessage(message);
     }
   }
@@ -705,6 +703,88 @@ void CMobileOpalDlg::OnTimer(UINT_PTR nIDEvent)
 }
 
 
+void CMobileOpalDlg::HandleMessage(OpalMessage & message)
+{
+  switch (message.m_type) {
+    case OpalIndRegistration :
+      switch (message.m_param.m_registrationStatus.m_status) {
+        case OpalRegisterSuccessful :
+        case OpalRegisterRestored :
+          SetStatusText(IDS_REGISTERED);
+          break;
+
+        case OpalRegisterRemoved :
+          SetStatusText(IDS_UNREGISTERED, message.m_param.m_registrationStatus.m_error);
+          break;
+
+        case OpalRegisterRetrying :
+          SetStatusText(IDS_REGISTERING);
+          break;
+
+        case OpalRegisterFailed :
+          SetStatusText(0, message.m_param.m_registrationStatus.m_error);
+      }
+      break;
+
+    case OpalIndMessageWaiting :
+      if (message.m_param.m_messageWaiting.m_type != NULL && *message.m_param.m_messageWaiting.m_type != '\0') {
+        CStringA msg;
+        msg.Format(IDS_MESSAGE_WAITING,
+                   message.m_param.m_messageWaiting.m_type,
+                   message.m_param.m_messageWaiting.m_party);
+        SetStatusText(0, msg);
+      }
+      break;
+
+    case OpalIndIncomingCall :
+      if (m_incomingCallToken.IsEmpty() && m_currentCallToken.IsEmpty()) {
+        m_incomingCallToken = message.m_param.m_incomingCall.m_callToken;
+        SetStatusText(IDS_INCOMING_CALL);
+        SetCallButton(true, IDS_ANSWER);
+        m_ctrlCallAddress.EnableWindow(false);
+        ShowWindow(true);
+        BringWindowToTop();
+      }
+      else {
+        OpalMessage command;
+        memset(&command, 0, sizeof(command));
+        command.m_type = OpalCmdClearCall;
+        command.m_param.m_clearCall.m_callToken = message.m_param.m_incomingCall.m_callToken;
+        command.m_param.m_clearCall.m_reason = OpalCallEndedByAnswerDenied;
+        OpalMessage * response = OpalSendMessage(m_opal, &command);
+        if (response != NULL)
+          OpalFreeMessage(response);
+        SetStatusText(IDS_BUSY);
+      }
+      break;
+
+    case OpalIndAlerting :
+      SetStatusText(IDS_RINGING);
+      break;
+
+    case OpalIndEstablished :
+      SetSpeakerMode(m_speakerphone);
+      SetStatusText(IDS_ESTABLISHED);
+      break;
+
+    case OpalIndUserInput :
+      SetStatusText(0, message.m_param.m_userInput.m_userInput);
+      break;
+
+    case OpalIndCallCleared :
+      if (m_currentCallToken  == message.m_param.m_callCleared.m_callToken ||
+          m_incomingCallToken == message.m_param.m_callCleared.m_callToken) {
+        m_incomingCallToken.Empty();
+        m_currentCallToken.Empty();
+
+        SetCallButton(true, IDS_CALL);
+        m_ctrlCallAddress.EnableWindow(true);
+
+        SetStatusText(IDS_READY, message.m_param.m_callCleared.m_reason);
+      }
+  }
+}
+
 void CMobileOpalDlg::OnOK()
 {
 #if WIN32_PLATFORM_WFSP
@@ -814,12 +894,14 @@ void CMobileOpalDlg::OnMenuOptionsGeneral()
   dlg.m_strDisplayName = GetOptionString(DisplayNameKey);
   dlg.m_strStunServer = GetOptionString(STUNServerKey);
   dlg.m_interfaceAddress = GetOptionString(InterfaceAddressKey, L"*");
+  dlg.m_AutoStartTxVideo = GetOptionInt(AutoStartTxVideoKey, true) != 0;
 
   if (dlg.DoModal() == IDOK) {
     SetOptionString(UserNameKey, dlg.m_strUsername);
     SetOptionString(DisplayNameKey, dlg.m_strDisplayName);
     SetOptionString(STUNServerKey, dlg.m_strStunServer);
     SetOptionString(InterfaceAddressKey, dlg.m_interfaceAddress);
+    SetOptionInt(AutoStartTxVideoKey, dlg.m_AutoStartTxVideo);
     InitialiseOPAL();
   }
 }
