@@ -23,17 +23,18 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 19582 $
- * $Author: rjongbloed $
- * $Date: 2008-02-22 07:04:40 +0000 (Fri, 22 Feb 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #pragma once
+#include "ScrollableDialog.h"
 
 
 // COptionsSIP dialog
 
-class COptionsSIP : public CDialog
+class COptionsSIP : public CScrollableDialog
 {
   DECLARE_DYNAMIC(COptionsSIP)
 
@@ -45,8 +46,6 @@ public:
   enum { IDD = IDD_OPTIONS_SIP };
 
 protected:
-  CCommandBar m_dlgCommandBar;
-
   virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
   virtual BOOL OnInitDialog();
 
