@@ -7,14 +7,16 @@
  *
  * Copyright (c) 2007 Equivalence Pty. Ltd.
  *
- * $Revision: 21111 $
- * $Author: rjongbloed $
- * $Date: 2008-09-22 01:32:48 +0000 (Mon, 22 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include "precompile.h"
 #include "main.h"
 
+#if OPAL_H323
+
 #include <ptclib/random.h>
 
 #ifdef H323_TRANSNEXUS_OSP
@@ -740,5 +742,7 @@ MyGatekeeperCall::~MyGatekeeperCall()
 #endif
 }
 
+#endif // OPAL_H323
+
 
 // End of File ///////////////////////////////////////////////////////////////
