@@ -24,28 +24,26 @@
  *
  * The author of this code is Derek J Smithies
  *
- *
- *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-
 #include <ptlib.h>
 #include <opal/buildopts.h>
-#include <ptclib/cypher.h>
 
+#if OPAL_IAX2
 
 #ifdef P_USE_PRAGMA
 #pragma implementation "ies.h"
 #endif
 
-
 #include <iax2/ies.h>
 #include <iax2/frame.h>
 #include <iax2/causecode.h>
 
+#include <ptclib/cypher.h>
+
 #define new PNEW
 
 IAX2Ie::IAX2Ie()
@@ -1002,6 +1000,8 @@ void IAX2IeReceivedOoo::PrintOn(ostream & str) const
 ////////////////////////////////////////////////////////////////////////////////
 
 
+#endif // OPAL_IAX2
+
 ////////////////////////////////////////////////////////////////////////////////
 /* The comment below is magic for those who use emacs to edit this file. */
 /* With the comment below, the tab key does auto indent to 4 spaces.     */
