@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21008 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 10:13:12 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -51,14 +51,13 @@ static OpalLIDRegistration * RegisteredLIDsListHead;
 ostream & operator<<(ostream & o, OpalLineInterfaceDevice::CallProgressTones t)
 {
   static const char * const CallProgressTonesNames[OpalLineInterfaceDevice::NumTones+1] = {
-    "NoTone", "DialTone", "RingTone", "BusyTone", "CongestionTone", "ClearTone", "MwiTone", "RoutingTone", "CNGTone", "CEDTone"
+    "NoTone", "DialTone", "RingTone", "BusyTone", "CongestionTone", "ClearTone", "MwiTone", "RoutingTone", "CNGTone", "CEDTone", "UserTone"
   };
-  if (t+1 < PARRAYSIZE(CallProgressTonesNames))
+  if (t+1 < PARRAYSIZE(CallProgressTonesNames) && CallProgressTonesNames[t+1] != NULL)
     return o << CallProgressTonesNames[t+1];
   else
-    return o << "Unknown";
+    return o << "UnknownTone:" << (unsigned)t;
 }
-
 #endif
 
 
@@ -1105,15 +1104,17 @@ PBoolean OpalLine::IsRinging(DWORD * cadence)
 
   if (device.IsLineRinging(lineNumber, cadence)) {
     ringTick = tick;
-    if (ringCount == 0) {
-      PTRACE(4, "LID\tRing start detected on line " << lineNumber);
-      ringCount = 1;
-    }
-    lastRingState = true;
-  }
-  else if (lastRingState && delta > ringInterCadenceTime) {
-    PTRACE(4, "LID\tRing cadence incremented on line " << lineNumber);
+    if (lastRingState)
+      return true;
+
+    PTRACE_IF(4, ringCount == 0, "LID\tRing start detected on line " << lineNumber);
     ringCount++;
+    lastRingState = true;
+    return true;
+  }
+
+  if (lastRingState && delta > ringInterCadenceTime) {
+    PTRACE(4, "LID\tRing cadence incremented on line " << lineNumber);
     lastRingState = false;
   }
 
